Example that goes with [introductory blog post](https://blog.dagworks.io/p/burr-develop-stateful-ai-applications).

## 🏃Quick start

```bash
pip install "burr[start]" jupyter
```

Run the notebook:

```bash
jupyter notebook
```

Then open `notebook.ipynb` and run the cells. Or <a target="_blank" href="https://colab.research.google.com/github/dagworks-inc/burr/blob/main/examples/simple-chatbot-intro/notebook.ipynb">
  <img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab"/>
</a>
